@@ -20,7 +20,7 @@ car.rgb = (1,0,0)
 # There all also a few shortcut properties to allow you to set multiple values
 # at a time: xy, uv, rgb, and rgba
 
-while True:
+while not pygame.event.peek(pygame.QUIT):
     rabbyt.clear((1,1,1))
 
     car.render()
