@@ -25,7 +25,7 @@ for i in range(400):
 collision_times = []
 c = pygame.time.Clock()
 last_fps = 0
-while True:
+while not pygame.event.peek(pygame.QUIT):
     c.tick()
     if pygame.time.get_ticks() - last_fps > 1000:
         print "FPS: ", c.get_fps()
