@@ -11,7 +11,7 @@ sprite.x = 100
 sprite.rgb = 0,1,1
 
 while not pygame.event.peek(pygame.QUIT):
-    rabbyt.clear()
+    rabbyt.clear((0,.5,.5,1))
     rabbyt.set_time(pygame.time.get_ticks())
     sprite.render()
     pygame.display.flip()
\ No newline at end of file
